Adjusts positions of all candidates for elimination in data.table after removing a candidate (due to the fact, that the positions may shift).
adjust_candidates(cand, cand_top_idx)data.table with candidates for elimination given by their
position indices.
numeric position index of candidate to be removed.
data.table candidates after any adjustments to position
indices of candidates.