Compute Results From Function Call with Object as Argument
get_results_for_object(obj, obj_arg_name, fun, ...,
tolerate_warnings = TRUE)list R object to be trimmed. _MUST_ inherit from the
'list' class.
character what is the name of the parameter, that
'obj' must be set to, when invoking 'fun'. Defaults to NULL, in which case
the function assumes, that the 'obj' matches the first parameter of 'fun'.
function function that must return the same results, when
invoked with 'obj' both before and after trimming.
other (named) arguments for 'fun'.
logical tolerate warnings (=TRUE) Or
not (=FALSE) from function call results?
results from function call.